@@ -155,7 +155,7 @@ class HankelTransform:
                              'object that was not constructed with a k_grid')
         return self._original_k_grid
 
-    def to_transform_r(self, function: np.ndarray) -> np.ndarray:
+    def to_transform_r(self, function: np.ndarray, axis: int = 0) -> np.ndarray:
         """Interpolate a function, assumed to have been given at the original radial
         grid points used to construct the ``HankelTransform`` object onto the grid required
         of use in the QDHT algorithm.
@@ -168,14 +168,18 @@ class HankelTransform:
         :parameter function: The function to be interpolated. Specified at the radial points
             :attr:`~.HankelTransform.original_radial_grid`.
         :type function: :class:`numpy.ndarray`
+        :parameter axis: Axis representing the radial dependence of `function`.
+        :type axis: :class:`int`
 
         :return: Interpolated function suitable to passing to
             :meth:`HankelTransform.qdht` (sampled at ``self.r``)
         :rtype: :class:`numpy.ndarray`
         """
-        return _spline(self.original_radial_grid, function, self.r)
+        if function.ndim == 1:
+            axis = 0
+        return _spline(self.original_radial_grid, function, self.r, axis)
 
-    def to_original_r(self, function: np.ndarray) -> np.ndarray:
+    def to_original_r(self, function: np.ndarray, axis: int = 0) -> np.ndarray:
         """Interpolate a function, assumed to have been given at the Hankel transform points
         ``self.r`` (as returned by :meth:`HankelTransform.iqdht`) back onto the original grid
         used to construct the ``HankelTransform`` object.
@@ -187,13 +191,17 @@ class HankelTransform:
         :parameter function: The function to be interpolated. Specified at the radial points
             ``self.r``.
         :type function: :class:`numpy.ndarray`
+        :parameter axis: Axis representing the radial dependence of `function`.
+        :type axis: :class:`int`
 
         :return: Interpolated function at the points held in :attr:`~.HankelTransform.original_radial_grid`.
         :rtype: :class:`numpy.ndarray`
         """
-        return _spline(self.r, function, self.original_radial_grid)
+        if function.ndim == 1:
+            axis = 0
+        return _spline(self.r, function, self.original_radial_grid, axis)
 
-    def to_transform_k(self, function: np.ndarray) -> np.ndarray:
+    def to_transform_k(self, function: np.ndarray, axis: int = 0) -> np.ndarray:
         """Interpolate a function, assumed to have been given at the original k
         grid points used to construct the ``HankelTransform`` object onto the grid required
         of use in the IQDHT algorithm.
@@ -206,15 +214,18 @@ class HankelTransform:
         :parameter function: The function to be interpolated. Specified at the k points
             :attr:`~.HankelTransform.original_k_grid`.
         :type function: :class:`numpy.ndarray`
+        :parameter axis: Axis representing the frequency dependence of `function`.
+        :type axis: :class:`int`
 
         :return: Interpolated function suitable to passing to
             :meth:`HankelTransform.qdht` (sampled at ``self.kr``)
         :rtype: :class:`numpy.ndarray`
         """
+        if function.ndim == 1:
+            axis = 0
+        return _spline(self.original_k_grid, function, self.kr, axis)
 
-        return _spline(self.original_k_grid, function, self.kr)
-
-    def to_original_k(self, function: np.ndarray) -> np.ndarray:
+    def to_original_k(self, function: np.ndarray, axis: int = 0) -> np.ndarray:
         """Interpolate a function, assumed to have been given at the Hankel transform points
         ``self.k`` (as returned by :meth:`HankelTransform.qdht`) back onto the original grid
         used to construct the ``HankelTransform`` object.
@@ -226,13 +237,17 @@ class HankelTransform:
         :parameter function: The function to be interpolated. Specified at the radial points
             ``self.k``.
         :type function: :class:`numpy.ndarray`
+        :parameter axis: Axis representing the frequency dependence of `function`.
+        :type axis: :class:`int`
 
         :return: Interpolated function at the points held in :attr:`~.HankelTransform.original_k_grid`.
         :rtype: :class:`numpy.ndarray`
         """
-        return _spline(self.kr, function, self.original_k_grid)
+        if function.ndim == 1:
+            axis = 0
+        return _spline(self.kr, function, self.original_k_grid, axis)
 
-    def qdht(self, fr: np.ndarray) -> np.ndarray:
+    def qdht(self, fr: np.ndarray, axis: int = -2) -> np.ndarray:
         r"""QDHT: Quasi Discrete Hankel Transform
 
         Performs the Hankel transform of a function of radius, returning
@@ -247,16 +262,24 @@ class HankelTransform:
 
         :parameter fr: Function in real space as a function of radius (sampled at ``self.r``)
         :type fr: :class:`numpy.ndarray`
+        :parameter axis: Axis over which to compute the Hankel transform.
+        :type axis: :class:`int`
 
         :return: Function in frequency space (sampled at ``self.v``)
         :rtype: :class:`numpy.ndarray`
         """
-        jr, jv = self._get_scaling_factors(fr)
+        if (fr.ndim == 1) or (axis == -2):
+            jr, jv = self._get_scaling_factors(fr)
 
-        fv = jv * np.matmul(self.T, (fr / jr))
-        return fv
+            fv = jv * np.matmul(self.T, (fr / jr))
+            return fv
+        else:
+            _fr = np.core.swapaxes(fr, axis, -2)
+            jr, jv = self._get_scaling_factors(_fr)
+            fv = jv * np.matmul(self.T, (_fr / jr))
+            return np.core.swapaxes(fv, axis, -2)
 
-    def iqdht(self, fv: np.ndarray) -> np.ndarray:
+    def iqdht(self, fv: np.ndarray, axis: int = -2) -> np.ndarray:
         r"""IQDHT: Inverse Quasi Discrete Hankel Transform
 
         Performs the inverse Hankel transform of a function of frequency, returning
@@ -267,25 +290,36 @@ class HankelTransform:
 
         :parameter fv: Function in frequency space (sampled at self.v)
         :type fv: :class:`numpy.ndarray`
+        :parameter axis: Axis over which to compute the Hankel transform.
+        :type axis: :class:`int`
 
         :return: Radial function (sampled at self.r) = IHT(fv)
         :rtype: :class:`numpy.ndarray`
         """
-        jr, jv = self._get_scaling_factors(fv)
-        fr = jr * np.matmul(self.T, (fv / jv))
-        return fr
+        if (fv.ndim == 1) or (axis == -2):
+            jr, jv = self._get_scaling_factors(fv)
+            fr = jr * np.matmul(self.T, (fv / jv))
+            return fr
+        else:
+            _fv = np.core.swapaxes(fv, axis, -2)
+            jr, jv = self._get_scaling_factors(_fv)
+            fr = jr * np.matmul(self.T, (_fv / jv))
+            return np.core.swapaxes(fr, axis, -2)
 
     def _get_scaling_factors(self, f: np.ndarray) -> Tuple[np.ndarray, np.ndarray]:
-        try:
-            n2 = f.shape[1]
-            jr = self.JR[:, np.newaxis] * np.ones((1, n2))
-            jv = self.JV[:, np.newaxis] * np.ones((1, n2))
-        except IndexError:
+        if f.ndim > 1:
+            n2 = list(f.shape)
+            n2[-2] = 1
+            _shape = np.ones_like(n2)
+            _shape[-2] = len(self.JR)
+            jr = np.reshape(self.JR, _shape) * np.ones(n2)
+            jv = np.reshape(self.JV, _shape) * np.ones(n2)
+        else:
             jr = self.JR
             jv = self.JV
         return jr, jv
 
 
-def _spline(x0: np.ndarray, y0: np.ndarray, x: np.ndarray) -> np.ndarray:
-    f = interpolate.interp1d(x0, y0, axis=0, fill_value='extrapolate', kind='cubic')
+def _spline(x0: np.ndarray, y0: np.ndarray, x: np.ndarray, axis: int) -> np.ndarray:
+    f = interpolate.interp1d(x0, y0, axis=axis, fill_value='extrapolate', kind='cubic')
     return f(x)
